@@ -1,14 +1,12 @@
 package Complete::Bash;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-12-30'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-#use Complete;
-
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -200,10 +198,15 @@ sub parse_cmdline {
                       } else {
                           $is_cur_word = defined($cword) && $cword==@words-1;
                       }
+                      #say "D:is_cur_word=$is_cur_word";
                       $chunk =
                           $2 ? _add_double_quoted($3, $is_cur_word) :
                               $5 ? _add_single_quoted($6) :
-                                  _add_unquoted($8, $is_cur_word, $after_ws);
+                              _add_unquoted($8, $is_cur_word, $after_ws);
+                      if ($is_cur_word && $pos > $point) {
+                          $chunk = substr($chunk, 0,
+                                          length($chunk)-($pos-$point)+1);
+                      }
                       if ($after_ws) {
                           push @words, $chunk;
                       } else {
@@ -530,7 +533,7 @@ Complete::Bash - Completion module for bash shell
 
 =head1 VERSION
 
-This document describes version 0.21 of Complete::Bash (from Perl distribution Complete-Bash), released on 2015-09-09.
+This document describes version 0.22 of Complete::Bash (from Perl distribution Complete-Bash), released on 2015-12-30.
 
 =head1 DESCRIPTION
 
@@ -633,6 +636,8 @@ C<com.company.product.whatever> or C<File::Spec::Unix>) you can use this mode
 
 =back
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -693,6 +698,8 @@ Caveats:
 Because they both expand to C<['--foo', '=', 'bar']>. But obviously
 C<Getopt::Long> does not regard the two as equivalent.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -748,6 +755,8 @@ argument. Otherwise, the next word is assumed to be this option's value.
 
 =back
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
